<?php

namespace Drupal\couchbasedrupal;

use Drupal\Core\StringTranslation\StringTranslationTrait;

class Installer {

  use StringTranslationTrait;

  public function requirements($phase) {

    $requirements = array();

    // Check for opcache size configuration.
    if ($phase == 'runtime') {

      /** @var \Drupal\couchbasedrupal\CouchbaseManager */
      $manager = \Drupal::service('couchbasedrupal.manager');

      $summary = '';

      foreach ($manager->listServers() as $server) {
        $bucket_name = $manager->getClusterDefaultBucketName($server);
        $bucket_password = $manager->getClusterDefaultBucketPassword($server);
        $bucket = $manager->getBucket($server, $bucket_name, $bucket_password);
        /** @var \CouchbaseBucketManager */
        $m = $bucket->manager();
        $info = $m->info();
        $quota = round($info['basicStats']['quotaPercentUsed'], 1);
        $diskUsed = format_size($info['basicStats']['diskUsed']);
        $dataUsed = format_size($info['basicStats']['dataUsed']);
        $memUsed = format_size($info['basicStats']['memUsed']);
        $summary = "bucket: {$server} | quota usage: {$quota}% | items:  {$info['basicStats']['itemCount']} | disk: {$diskUsed} | data: {$dataUsed} | memory: {$memUsed} | type: {$info['bucketType']}";
      }

      $requirements['couchbase_usage'] = array(
        'title' => $this->t('Couchbase storage'),
        'value' => '',
        'severity' => REQUIREMENT_OK,
        'description' => $summary
      );


    }

    return $requirements;
  }
}
